@@ -63,13 +63,13 @@ case "i documenti attuali verranno cancellati":	$messaggio = "nuvarande dokument
 case "Ripristina i documenti dal file":  	$messaggio = "&Aring;terst&auml;ll dokument fr&aring;n fil"; break;
 case "Documenti ripristinati":  		$messaggio = "Dokument &aring;terst&auml;llda"; break;
 case "Backup completo":  			$messaggio = "Komplett backup"; break;
-case "Includi i modelli internet":  		$messaggio = "Inkludera internetmallar"; break;
 case "creato il":  				$messaggio = "skapad"; break;
 case "alle":  					$messaggio = "vid"; break;
+case "Backup":  				$messaggio = "Backup"; break;
 case "Normalmete 5432 o 5433 per Postgresql o 3306 per Mysql":	$messaggio = "Normally 5432 or 5433 for Postgresql or 3306 for Mysql"; break;
-case "La versione attuale di hoteldruid e quella del file non coincidono":	$messaggio = "The current version of hoteldruid and the one of the file are not the same"; break;
 case "Sistema di backup per HotelDruid":  	$messaggio = "Backup system for HotelDruid"; break;
 case "opzionale, utile per più installazioni di hoteldruid nello stesso database":	$messaggio = "optional, useful for more installations of hoteldruid in the same database"; break;
+case "Includi le pagine per il sito web":  	$messaggio = "Include website pages"; break;
 case "copia":  					$messaggio = "copy"; break;
 case "il file di backup dai documenti predefiniti in":	$messaggio = "the backup file from default documents in"; break;
 case "file copiato":  				$messaggio = "file copied"; break;
@@ -82,6 +82,8 @@ case "alcuni dati di questi anni potrebbero comunque venir persi":	$messaggio =
 case "tutti i documenti contenuti nel file":	$messaggio = "all the documents contained in file"; break;
 case "solo il documento":  			$messaggio = "only document"; break;
 case "Raggiunto il limite giornaliero di backup":	$messaggio = "You have reached the limit of daily backups"; break;
+case "La versione attuale di HotelDruid e quella del file non coincidono":	$messaggio = "The current version of HotelDruid and the one of the file are not the same"; break;
+case "La versione attuale e quella del file non coincidono":	$messaggio = "The current version and the one of the file are not the same"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
