@@ -232,6 +232,7 @@ case "Importa":  				$messaggio = "Importera"; break;
 case "con i servizi opzionali selezionati":  	$messaggio = "med valda extratj&auml;nster"; break;
 case "chiedere":  				$messaggio = "ask"; break;
 case "il":  					$messaggio = "the"; break;
+case "Crea Pagine Web":  			$messaggio = "Create Web Pages"; break;
 case "Crea pagine per il sito web":  		$messaggio = "Create website pages"; break;
 case "Postgresql":  				$messaggio = "Postgresql"; break;
 case "Mysql":  					$messaggio = "Mysql"; break;
@@ -242,6 +243,8 @@ case "Motivazioni delle regole di assegnazone 1 per disponibilità condizionata
 case "Crea la pagina per la disponibilità":  	$messaggio = "Create availability page"; break;
 case "C'è ancora disponibilità":		$messaggio = "There is still availability"; break;
 case "E' necessario inserire il numero di persone per questa tipologia":	$messaggio = "The number of people is needed for this type"; break;
+case "Email alternativa":  			$messaggio = "Alternative email"; break;
+case "Email certificata (PEC) o codice destinatario":	$messaggio = "Certified email"; break;
 case "Periodo":  				$messaggio = "Period"; break;
 case "Una pagina chiamata":  			$messaggio = "A page called"; break;
 case "è stata creata nella directory":  	$messaggio = "has been created in folder"; break;
@@ -264,7 +267,7 @@ case "Si è sicuri di voler importare le pagine dalla cartella":	$messaggio = "A
 case "eventuali pagine già presenti nella cartella":	$messaggio = "pages eventually already present in directory"; break;
 case "verranno <b style=\"font-weight: normal; color: red;\">sovrascritte</b>":	$messaggio = "will be <b style=\"font-weight: normal; color: red;\">overwritten</b>"; break;
 case "Pagine importate":  			$messaggio = "Pages imported"; break;
-case "Utilizzare le liste di nazioni, regioni, etc. dell'utente":	$messaggio = "Use lists of nations, regions, etc. from user"; break;
+case "Utilizzare le personalizzazioni (tipi di persone, liste di nazioni, regioni, ecc.) dell'utente":	$messaggio = "Use customizations (people types, lists of nations, regions, etc.) from user"; break;
 case "Url del file css per la modalità frame":	$messaggio = "Url of css file for framed mode"; break;
 case "Utilizza per l'aspetto della pagina":  	$messaggio = "Use for page appearance"; break;
 case "html personalizzato":  			$messaggio = "custom html"; break;
@@ -275,7 +278,7 @@ case "Data di partenza":  			$messaggio = "Departure date"; break;
 case "Tipologia":  				$messaggio = "Type"; break;
 case "default - frame orizzontale":  		$messaggio = "default - horizontal frame"; break;
 case "Condizioni da accettare nella form":  	$messaggio = "Agreements to be accepted in the form"; break;
-case "nomi dall'utente delle liste":		$messaggio = "names from lists user"; break;
+case "nomi dall'utente delle personalizzazioni":	$messaggio = "names from customizations user"; break;
 case "Accetto":  				$messaggio = "I accept"; break;
 case "documento":  				$messaggio = "document"; break;
 case "larghezza":  				$messaggio = "width"; break;
@@ -320,6 +323,16 @@ case "non sono associati a tariffe, alcune loro caratteristiche potrebbero venir
 case "Mostrare le date passate?":  		$messaggio = "Show past dates?"; break;
 case "titolo html":  				$messaggio = "html title"; break;
 case "titolo":  				$messaggio = "title"; break;
+case "Si deve inserire almeno una persona che possa essere legalmente responsabile":	$messaggio = "You must include at least one person who can be legally responsible"; break;
+case "Solo quando non c'è disponibilità":  	$messaggio = "Only when there is no availability"; break;
+case "Sempre":  				$messaggio = "Always"; break;
+case "Raggruppamento":  			$messaggio = "Grouping"; break;
+case "Valuta della caparra":  			$messaggio = "Deposit currency"; break;
+case "Seconda email":  				$messaggio = "Second email"; break;
+case "PEC o codice destinatario":  		$messaggio = "Certified email"; break;
+case "Url del file javascript per la modalità frame":	$messaggio = "Url of javascript file for framed mode"; break;
+case "URL file javascript":  			$messaggio = "URL of javascript file"; break;
+case "non deve contenere \"php\" e deve terminare con \".js\"":	$messaggio = "must not contain \"php\" and must end with \".js\""; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
@@ -333,9 +346,9 @@ case "mdl_disponibilita":  			$messaggio = "tillganglighet_tpl"; break;
 else {
 switch ($messaggio) {
 
-# NAMES OF VARIABLES: for translation leave the beginning as var_ and use only a-z, A-Z, 
-# 0-9 and _ (underscore). No spaces, no accents! There must not be 2 with the same name.
-# NOTE: names of variables are only shown when editing files, actually they don't need to be translated
+# NAMES OF VARIABLES: for translation leave the beginning as var_ and use only ASCII a-z, A-Z, 0-9 
+# and _ (underscore). No spaces, no accents! No special characters! There must not be 2 with the same name.
+# NOTE: names of variables are only shown when editing files, actually *they don't need to be translated*
 case "var_fr_con_i_servizi_opzionali_selezionati":	$messaggio = "var_with_selected_optional_services"; break;
 
 case "var_nome_pagina":  			$messaggio = "var_page_name"; break;
@@ -429,12 +442,16 @@ case "var_fr_di":  				$messaggio = "var_phr_of"; break;
 case "var_fr_Nuovo_controllo":  		$messaggio = "var_phr_New_check"; break;
 case "var_fr_Nome":  				$messaggio = "var_phr_Name"; break;
 case "var_fr_Email":  				$messaggio = "var_phr_Email"; break;
+case "var_fr_Email_alternativa":  		$messaggio = "var_phr_Alternative_email"; break;
+case "var_fr_Email_certificata_o_codice_destinatario":	$messaggio = "var_phr_Certified_email"; break;
 case "var_fr_Commento":  			$messaggio = "var_phr_Comment"; break;
 case "var_fr_Invia_la_richiesta_di_prenotazione":	$messaggio = "var_phr_Send_the_request_for_reservation"; break;
 case "var_fr_Richiesta_di_prenotazione_inviata":	$messaggio = "var_phr_Request_for_reservation_sent"; break;
 case "var_fr_Non_e_stato_possibile_inviare_la_richiesta":	$messaggio = "var_phr_It_was_not_possible_to_send_the_request"; break;
 case "var_fr_da":  				$messaggio = "var_phr_from2"; break;
 case "var_fre_Email":  				$messaggio = "var_phre_Email"; break;
+case "var_fre_Email_alternativa":  		$messaggio = "var_phre_Alternative_email"; break;
+case "var_fre_Email_certificata_o_codice_destinatario":	$messaggio = "var_phre_Certified_email"; break;
 case "var_fre_Nome":  				$messaggio = "var_phre_Name"; break;
 case "var_fre_Commento":  			$messaggio = "var_phre_Comment"; break;
 case "var_fre_Periodo":  			$messaggio = "var_phre_Period"; break;
@@ -447,6 +464,7 @@ case "var_fre_Prezzo_totale":  			$messaggio = "var_phre_Total_price"; break;
 case "var_fre_Riferimento":  			$messaggio = "var_phre_Reference"; break;
 case "var_fre_Caparra":  			$messaggio = "var_phre_Deposit"; break;
 case "var_fre_Richesta_prenotazione":  		$messaggio = "var_phre_Reservation_request"; break;
+case "var_fre_Valuta_della_caparra":  		$messaggio = "var_phre_Deposit_currency"; break;
 case "var_fr_Richesta_prenotazione":  		$messaggio = "var_phr_Reservation_request"; break;
 case "var_periodi_menu":  			$messaggio = "var_menu_periods"; break;
 case "var_fr_appartamenti":  			$messaggio = "var_phr_apartments"; break;
@@ -510,6 +528,8 @@ case "var_utente_messaggio":  			$messaggio = "var_message_user"; break;
 case "var_chiedi_cognome":  			$messaggio = "var_ask_surname"; break;
 case "var_chiedi_nome":  			$messaggio = "var_ask_name"; break;
 case "var_chiedi_email":  			$messaggio = "var_ask_email"; break;
+case "var_chiedi_email2":  			$messaggio = "var_ask_email2"; break;
+case "var_chiedi_email_cert":  			$messaggio = "var_ask_cert_email"; break;
 case "var_chiedi_sesso":  			$messaggio = "var_ask_sex"; break;
 case "var_chiedi_datanascita":  		$messaggio = "var_ask_birthdate"; break;
 case "var_chiedi_documento":  			$messaggio = "var_ask_document"; break;
@@ -527,6 +547,7 @@ case "var_chiedi_codfiscale":  			$messaggio = "var_ask_fiscalcode"; break;
 case "var_chiedi_partitaiva":  			$messaggio = "var_ask_vatnumber"; break;
 case "var_chiedi_commento":  			$messaggio = "var_ask_comment"; break;
 case "var_chiedi_oracheckin":  			$messaggio = "var_ask_checkintime"; break;
+case "var_chiedi_valutapagamento":  		$messaggio = "var_ask_paymentcurrency"; break;
 case "var_chiedi_metodopagamento":  		$messaggio = "var_ask_paymentmethod"; break;
 case "var_metodi_pagamento_da_chiedere":  	$messaggio = "var_payment_methods_to_ask"; break;
 case "var_nomi_metodi_pagamento_imposti":  	$messaggio = "var_imposed_payment_methods_names"; break;
@@ -552,6 +573,7 @@ case "var_fr_Fax":  				$messaggio = "var_phr_Fax"; break;
 case "var_fr_Codice_fiscale":  			$messaggio = "var_phr_Fiscal_code"; break;
 case "var_fr_Partita_iva":  			$messaggio = "var_phr_VAT_number"; break;
 case "var_fr_Orario_stimato_di_arrivo":  	$messaggio = "var_phr_Estimated_arrival_time"; break;
+case "var_fr_Valuta_della_caparra":		$messaggio = "var_phr_Deposit_currency"; break;
 case "var_fr_Metodo_di_pagamento_della_caparra":	$messaggio = "var_phr_Deposit_payment_method"; break;
 case "var_fre_Cognome":  			$messaggio = "var_phre_Surname"; break;
 case "var_fre_Genere":  			$messaggio = "var_phre_Gender"; break;
@@ -593,8 +615,10 @@ case "var_fr_posizioni_vicine":  		$messaggio = "var_phr_nearby_positions"; brea
 case "var_fr_con_posizioni_vicine":  		$messaggio = "var_phr_with_nearby_positions"; break;
 case "var_fr_Codice_promozionale":  		$messaggio = "var_phr_Promotional_code"; break;
 case "var_fr_Codice_promozionale_applicato":  	$messaggio = "var_phr_Promotional_code_applied"; break;
+case "var_fr_Si_deve_inserire_almeno_una_persona_che_possa_ecc":	$messaggio = "var_phr_You_must_include_at_least_one_person_who_can_etc"; break;
 case "var_":  		$messaggio = "var_"; break;
 case "var_":  		$messaggio = "var_"; break;
+case "var_file_js_frame":  			$messaggio = "var_framed_js_file"; break;
 } # fine switch ($messaggio)
 } # fine else if (substr($messaggio,0,4) != "var_")
 
