@@ -223,6 +223,7 @@ case "Sulla":  					$messaggio = "On"; break;
 case "p":  					$messaggio = "p"; break;
 case "Se":  					$messaggio = "If"; break;
 case "Se si inseriscono":  			$messaggio = "If"; break;
+case "Crea Prezzi":  				$messaggio = "Insert Prices"; break;
 case "Inserzione per giorni":			$messaggio = "Insertion on daily basis"; break;
 case "Inserzione per settimane":  		$messaggio = "Insertion on weekly basis"; break;
 case "Costo aggiuntivo già esistente":  	$messaggio = "Extra cost already inserted"; break;
@@ -275,7 +276,6 @@ case "opzionale":  				$messaggio = "optional"; break;
 case "Costi combinati":  			$messaggio = "Combined costs"; break;
 case "Inserimento rapido di un nuovo costo aggiuntivo per":	$messaggio = "Fast insertion of a new extra cost for"; break;
 case "permanenza minima":  			$messaggio = "minimum stay"; break;
-case "numero di bambini":  			$messaggio = "number of children"; break;
 case "letto aggiuntivo":  			$messaggio = "extra bed"; break;
 case "offerta speciale":  			$messaggio = "special offer"; break;
 case "inserisci":  				$messaggio = "insert"; break;
@@ -283,10 +283,8 @@ case "Inserisci il costo aggiuntivo":  		$messaggio = "Insert the extra cost"; b
 case "Numero minimo di giorni":  		$messaggio = "Minimum number of days"; break;
 case "Applicato alle tariffe":  		$messaggio = "Applied to rates"; break;
 case "Periodi in cui viene applicato il costo":	$messaggio = "Periods in which the cost is applied"; break;
-case "Valore dello sconto per ogni bambino":  	$messaggio = "Discount value for each child"; break;
 case "del prezzo di una persona":  		$messaggio = "of the price for one person"; break;
 case "solo per tariffe con prezzi a persona":  	$messaggio = "only for rates with per person prices"; break;
-case "con questo costo si deve includere il numero di bambini anche nel numero di persone":	$messaggio = "with this cost the number of children must be included in the number of people too"; break;
 case "Valore del letto aggiuntivo":  		$messaggio = "Value of the extra bed"; break;
 case "Valore dello sconto":  			$messaggio = "Discount value"; break;
 case "del prezzo totale":  			$messaggio = "of total price"; break;
@@ -313,6 +311,16 @@ case "i prezzi di alcuni periodi <em>non sono stati inseriti</em> perchè import
 case "limite non considerato per le persone aggiuntive nelle interconnessioni":	$messaggio = "limit not considered for additional people in interconnections"; break;
 case "Seleziona adesso questo costo anche per tutti gli utenti che non hanno privilegi per usare tutti i costi":	$messaggio = "Select now this cost also for all the users that don't have privileges to use all the costs"; break;
 case "Aggiungi adesso questo costo a tutte le pagine create per il sito web":	$messaggio = "Add now this cost to all existing website pages"; break;
+case "Se si moltiplica per il numero di persone":	$messaggio = "When multiplying by the number of people"; break;
+case "escludi":  				$messaggio = "exclude"; break;
+case "includi solo":  				$messaggio = "include only"; break;
+case "questi tipi":  				$messaggio = "these types"; break;
+case "Mostrare come tipo di persona":  		$messaggio = "Display as person type"; break;
+case "Applicare la percentuale del tipo di persona al prezzo del costo":	$messaggio = "Apply the percentage of the person type to the price of the cost"; break;
+case "numero di neonati":  			$messaggio = "number of infants"; break;
+case "Valore per ogni neonato":  		$messaggio = "Value for each infant"; break;
+case "con questo costo il numero di neonati non è incluso nel numero di persone":	$messaggio = "with this cost the number of infants is not included in the number of people"; break;
+case "Neonati (0-23 mesi)":  			$messaggio = "Infants (0-23 months)"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
