@@ -39,6 +39,7 @@ case "assegna automaticamente come numero di persone":	$messaggio = "automatiskt
 case "se non si inserisce nessun altro numero":	$messaggio = "om inga andra rum har lagts till"; break;
 case "La tariffa scelta ha già un numero di persone associato, cancella la regola prima di inserirne una nuova":	$messaggio = "Valt pris har redan ett tilldelat antal personer. Ta bort regeln f&ouml;re en ny l&auml;ggs till"; break;
 case "Si deve inserire il numero di persone da associare":	$messaggio = "Du m&aring;ste v&auml;lja antalet personer som ska associeras"; break;
+case "Crea Regole":  				$messaggio = "Create Rules"; break;
 case "Eccezioni alla regola":  			$messaggio = "Exceptions to rule"; break;
 case "e mancano meno di":  			$messaggio = " and less than"; break;
 case "giorni":					$messaggio = "days are missing"; break;
@@ -61,6 +62,14 @@ case "della regola 2 mancanti nella eccezione alla regola":	$messaggio = "in rul
 case "nella regola 2 di questa tariffa che non possono ospitare":	$messaggio = "in the rule 2 for this rate that can't host"; break;
 case "persone":  				$messaggio = "people"; break;
 case "nella regola di assegnazione 2 di questa tariffa":	$messaggio = "in the assignment rule 2 for this rate"; break;
+case "Regole esistenti":  			$messaggio = "Existing rules"; break;
+case "Cancella o ridimensiona queste regole":  	$messaggio = "Delete or scale down these rules"; break;
+case "Cancella":  				$messaggio = "Delete"; break;
+case "Ridimensiona":  				$messaggio = "Scale down"; break;
+case "Modifica la regola":  			$messaggio = "Modify rule"; break;
+case "chiusure":  				$messaggio = "closures"; break;
+case "numero di persone":  			$messaggio = "number of people"; break;
+case "utente inserimento":  			$messaggio = "inserting user"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
