@@ -52,6 +52,7 @@ case "cancella":  				$messaggio = "ta bort"; break;
 case "Si è sicuri di voler <b style=\"font-weight: normal; color: red;\">cancellare</b> l'utente":	$messaggio = "&Auml;r du s&auml;ker p&aring; att du vill <b style=\"font-weight: normal; color: red;\">ta bort</b> anv&auml;ndaren"; break;
 case "SI":  					$messaggio = "JA"; break;
 case "NO":  					$messaggio = "NEJ"; break;
+case "Gestione Utenti":  			$messaggio = "Users Management"; break;
 case "Gestione degli utenti di hoteldruid":	$messaggio = "HotelDruid users management"; break;
 case "privilegi e personalizzazioni":  		$messaggio = "privileges and customizations"; break;
 case "solo i privilegi":  			$messaggio = "only privileges"; break;
@@ -62,6 +63,7 @@ case "privilegi e gruppi":  			$messaggio = "privileges and groups"; break;
 case "personalizzazioni e gruppi":  		$messaggio = "customizations and groups"; break;
 case "solo i gruppi":  				$messaggio = "only groups"; break;
 case "Gruppi importati":  			$messaggio = "Groups imported"; break;
+case "Gestione degli utenti":			$messaggio = "Users management"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
