@@ -112,6 +112,7 @@ case "Titolo":  				$messaggio = "Titel"; break;
 case "Il titolo verrà cambiato da":  		$messaggio = "Tteln kommer &auml;ndras fr&aring;n"; break;
 case "Il <b>titolo</b> verrà cancellato":  	$messaggio = "<b>Titeln</b> kommer tas bort"; break;
 case "CVC":  					$messaggio = "CVC"; break;
+case "Modifica Cliente":  			$messaggio = "Modify Client"; break;
 case "Piazzale":  				$messaggio = "Boulevard"; break;
 case "documento di tipo":  			$messaggio = "document type"; break;
 case "visualizza":  				$messaggio = "view"; break;
@@ -155,6 +156,12 @@ case "questo valore è gia stato cancellato, questa è l'ultima volta che viene
 case "Questo valore verrà visualizzato solo un'altra volta":	$messaggio = "You'll be able to see this value only one more time"; break;
 case "Cancellalo ora":  			$messaggio = "Delete it now"; break;
 case "CVC cancellato":  			$messaggio = "CVC deleted"; break;
+case "2ª email":  				$messaggio = "2nd email"; break;
+case "PEC o codice destinatario":  		$messaggio = "Certified email"; break;
+case "La seconda email verrà cambiata da":  	$messaggio = "The second email will be changed from"; break;
+case "L'email certificata (PEC) o il codice destinatario verrà cambiato da":	$messaggio = "The certified email will be changed from"; break;
+case "La <b>seconda email</b> verrà cancellata":	$messaggio = "The <b>second email</b> will be deleted"; break;
+case "L'<b>email certificata (PEC) o il codice destinatario</b> verrà cancellato":	$messaggio = "The <b>certified email</b> will be deleted"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
