@@ -15,6 +15,7 @@ case "Modifica i dati del cliente":  		$messaggio = "&Auml;ndra kunddata"; break
 case "La prenotazione è dell'anno precedente, si potrà modificare solo la data finale":	$messaggio = "Bokningen &auml;r fr&aring;n ett tidigare &aring;r. Du kommer bara kunna &auml;ndra slutdatumet"; break;
 case "settimane":  				$messaggio = "veckor"; break;
 case "giorni":  				$messaggio = "dagar"; break;
+case "giorno":  				$messaggio = "day"; break;
 case "dal":  					$messaggio = "fr&aring;n"; break;
 case "al":  					$messaggio = "till"; break;
 case "cambia in":  				$messaggio = "&auml;ndra till"; break;
@@ -221,6 +222,7 @@ case "non sono disponibili nell'inventario":  	$messaggio = "&auml;r inte tillg&
 case "pren.":  					$messaggio = "bokn."; break;
 case "tutte":  					$messaggio = "all"; break;
 case "ln.":  					$messaggio = "ln."; break;
+case "Modifica Prenotazioni":  			$messaggio = "Modify reservations"; break;
 case "documento di tipo":  			$messaggio = "document type"; break;
 case "visualizza":  				$messaggio = "view"; break;
 case "visualizza il documento":  		$messaggio = "view document"; break;
@@ -252,6 +254,21 @@ case "La <b>tariffa</b> richiesta è <span class=\"colred\">chiusa</span> in que
 case "cambia il commento":  			$messaggio = "change comment"; break;
 case "Il commento":  				$messaggio = "Comment"; break;
 case "verrà cambiato":  			$messaggio = "will be changed"; break;
+case "per ":  					$messaggio = "for "; break;
+case "Il numero di":  				$messaggio = "The number of"; break;
+case "Valuta":  				$messaggio = "Currency"; break;
+case "Valuta caparra":  			$messaggio = "Deposit currency"; break;
+case "Al cambio attuale":  			$messaggio = "At current exchange rate"; break;
+case "email":  					$messaggio = "email"; break;
+case "2ª email":  				$messaggio = "2nd email"; break;
+case "PEC/codice":  				$messaggio = "certified email"; break;
+case "cancella in modo permanente":  		$messaggio = "delete permanently"; break;
+case "in modo permanente":  			$messaggio = "permanently"; break;
+case "Prenotazione cancellata":  		$messaggio = "Deleted reservation"; break;
+case "Prenotazioni cancellate":  		$messaggio = "Deleted reservations"; break;
+case "Data o orario stimato di entrata <span class=\"colred\">errato</span>":	$messaggio = "<span class=\"colred\">Wrong</span> estimated check-in time or date"; break;
+case "Data cancellazione":  			$messaggio = "Deletion date"; break;
+case "Cancellata dall'utente":  		$messaggio = "Deleted by user"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
