@@ -57,6 +57,7 @@ case "solo al documento":  			$messaggio = "bara f&ouml;r dokumentet"; break;
 case "solo all'inizio delle ripetizioni delle prenotazioni":	$messaggio = "bara n&auml;r bokningsrepetitioner startas"; break;
 case "in tutte le ripetizioni delle prenotazioni":	$messaggio = "i alla bokningsrepetitioner"; break;
 case "azzera l'array":  			$messaggio = "icke-inst&auml;lld array"; break;
+case "Modifica Variabili Documenti":  		$messaggio = "Modify Documents Variables"; break;
 case "Utilizzare una variabile personalizzata che finisce con \"_p\" per aggiungervi i separatori delle migliaia e 2 decimali dopo l'operazione":	$messaggio = "Use a custom variable that ends with \"_p\" to add the thousands separators and 2 decimals after the operation"; break;
 case "troncare":  				$messaggio = "truncate"; break;
 case "valori progressivi tra le date selezionate":	$messaggio = "progressive values between selected dates"; break;
@@ -119,6 +120,11 @@ case "codificato per URL":  			$messaggio = "encoded for URL"; break;
 case "codificato in ASCII":  			$messaggio = "encoded in ASCII"; break;
 case "in ASCII esteso":  			$messaggio = "in extended ASCII"; break;
 case "codificato con MD5":  			$messaggio = "encoded with MD5"; break;
+case "solo nelle ripetizioni dei documenti salvati":	$messaggio = "only inside repetitions of saved documents"; break;
+case "Condizioni eliminate":  			$messaggio = "Deleted conditions"; break;
+case "tutti i documenti":  			$messaggio = "all documents"; break;
+case "documento":  				$messaggio = "document"; break;
+case "anche condizioni":  			$messaggio = "also conditions"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
