@@ -285,6 +285,8 @@ case "e in quelli di utenti appartenenti ai suoi gruppi":	$messaggio = "och i do
 case "non potrà <b>modificare le quantità dei beni</b>":	$messaggio = "kommer inte kunna <b>&auml;ndra f&ouml;rem&aring;lskvantitet</b>"; break;
 case "potrà <b>modificare le quantità dei beni</b>":	$messaggio = "kommer kunna <b>&auml;ndra f&ouml;rem&aring;lskvantitet</b>"; break;
 case "nel":  					$messaggio = "in"; break;
+case "e":  					$messaggio = "and"; break;
+case "Privilegi Utenti":  			$messaggio = "Users Privileges"; break;
 case "Possibilità di inserire la caparra e le commissioni":	$messaggio = "Possibility to insert deposit and commissions"; break;
 case "Possibilità di inserire il commento":  	$messaggio = "Possibility to insert the comment"; break;
 case "Possibilità di inserire i commenti personalizzati":	$messaggio = "Possibility to insert custom comments"; break;
@@ -352,6 +354,47 @@ case "non potrà più modificare i <b>documenti come API</b>":	$messaggio = "wil
 case "Gestione della password per le carte di credito":	$messaggio = "Management of credit cards password"; break;
 case "potrà gestire la <b>password per le carte di credito</b>":	$messaggio = "will be able to manage the <b>credit cards password</b>"; break;
 case "non potrà più gestire la <b>password per le carte di credito</b>":	$messaggio = "will not be able to manage the <b>credit cards password</b>"; break;
+case "senza mostrare il valore":  		$messaggio = "without showing the value"; break;
+case "mostrando il valore":  			$messaggio = "showing the value"; break;
+case "senza mostrare i valori":  		$messaggio = "without showing the values"; break;
+case "mostrando i valori":  			$messaggio = "showing the values"; break;
+case "Possibilità di modificare l'utente che ha inserito":	$messaggio = "Possibility to modify the inserting user"; break;
+case "con tutti gli utenti":  			$messaggio = "with all users"; break;
+case "solo con utenti dei suoi gruppi":  	$messaggio = "only with users from his groups"; break;
+case "mostrando l'utente":  			$messaggio = "showing the user"; break;
+case "senza mostrare l'utente":  		$messaggio = "without showing the user"; break;
+case "potrà modificare l'<b>utente</b> che ha inserito la prenotazione nel":	$messaggio = "will be able to modify the <b>user</b> that inserted the reservation in"; break;
+case "non potrà modificare l'<b>utente</b> che ha inserito la prenotazione nel":	$messaggio = "will not be able to modify the <b>user</b> that inserted the reservation in"; break;
+case "senza mostrarla":  			$messaggio = "without showing it"; break;
+case "senza mostrarli":  			$messaggio = "without showing them"; break;
+case "Modifica delle tipologie di persone":  	$messaggio = "Modify people types"; break;
+case "potrà modificare le sue <b>tipologie di persone</b>":	$messaggio = "will be able to modify his <b>people types</b>"; break;
+case "non potrà più modificare le sue <b>tipologie di persone</b>":	$messaggio = "will not be able to modify his <b>people types</b>"; break;
+case "Modifica delle valute":  			$messaggio = "Modify currencies"; break;
+case "potrà modificare le sue <b>valute</b>":  	$messaggio = "will be able to modify his <b>currencies</b>"; break;
+case "non potrà più modificare le sue <b>valute</b>":	$messaggio = "will not be able to modify his <b>currencies</b>"; break;
+case "solo per lui":  				$messaggio = "only for him"; break;
+case "anche per i suoi gruppi":  		$messaggio = "also for his groups"; break;
+case "anche per tutti gli utenti":  		$messaggio = "also for all the users"; break;
+case "e quelle di utenti appartenenti ai suoi gruppi":	$messaggio = "and the ones from users belonging to his groups"; break;
+case "e quelle di tutti gli altri utenti":  	$messaggio = "and the ones from all users"; break;
+case "Cancellare le prenotazioni in modo permanente":	$messaggio = "Delete reservations permanently"; break;
+case "non <b>cancellerà mai in modo permanente</b> le prenotazioni nel":	$messaggio = "will <b>never permanently delete</b> reservations in"; break;
+case "potrà scegliere se <b>cancellare in modo permanente</b> le prenotazioni nel":	$messaggio = "will choose if <b>permanently delete</b> reservations in"; break;
+case "<b>cancellerà sempre in modo permanete</b> le prenotazioni nel":	$messaggio = "will <b>always permanently delete</b> reservations in"; break;
+case "Possibilità di modificare le <i>regole di assegnazione</i>":	$messaggio = "Possibility to modify the <i>assignment rules</i>"; break;
+case "non potrà modifcare le <b>regole di assegnazione 1</b> nel":	$messaggio = "will not be able to modify the <b>assignment rules 1</b> in"; break;
+case "potrà modifcare le <b>regole di assegnazione 1</b> nel":	$messaggio = "will be able to modify the <b>assignment rules 1</b> in"; break;
+case "non potrà modifcare le <b>regole di assegnazione 2 e 3</b> nel":	$messaggio = "will not be able to modify the <b>assignment rules 2 and 3</b> in"; break;
+case "potrà modifcare le <b>regole di assegnazione 2 e 3</b> nel":	$messaggio = "will be able to modify the <b>assignment rules 2 and 3</b> in"; break;
+case "assegnazione persone":  			$messaggio = "people assignment"; break;
+case "Creazione e modifica delle pagine per il sito web":	$messaggio = "Create and modify website pages"; break;
+case "Solo con i costi aggiuntivi":  		$messaggio = "only with extra costs"; break;
+case "potrà creare e modificare le <b>pagine per il sito web</b>":	$messaggio = "will be able to create and modify <b>website pages</b>"; break;
+case "potrà modificare le <b>pagine per il sito web</b> solo quando crea e modifica i costi aggiuntivi":	$messaggio = "will be able to modify <b>website pages</b> only when creating and modifying extra costs"; break;
+case "non potrà più creare e modificare le <b>pagine per il sito web</b>":	$messaggio = "will not be able to create and modify <b>website pages</b>"; break;
+case "solo per tariffe":  			$messaggio = "only for rates"; break;
+case "per entrambi":  				$messaggio = "for both"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
