@@ -106,9 +106,8 @@ case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 3 per la":
 case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 4 per la":	$messaggio = "&Auml;r du s&auml;ker p&aring; att du vill <b>ta bort</b> &ouml;verl&aring;telseregel 4 f&ouml;r"; break;
 case "La regola di assegnazione è stata cancellata":	$messaggio = "&Ouml;verl&aring;tningsregeln har tagits bort"; break;
 case "La regola di assegnazione è già stata cancellata":	$messaggio = "&Ouml;verl&aring;tningsregeln har redan tagits bort"; break;
-case "Tabella con le regole di assegnazione 1 del":	$messaggio = "Tabell med &ouml;verl&aring;tningsregel 1 av"; break;
+case "del":  					$messaggio = "f&ouml;r"; break;
 case "Motivazione":  				$messaggio = "Motivering"; break;
-case "Tabella con le regole di assegnazione 2 del":	$messaggio = "Tabell med &ouml;verl&aring;tningsregel 2 av"; break;
 case "Tariffa":  				$messaggio = "Pris"; break;
 case "Inserisci nuove regole":  		$messaggio = "L&auml;gg till nya regler"; break;
 case "Il numero inserito esiste già":  		$messaggio = "Det angivna numret finns redan"; break;
@@ -159,7 +158,6 @@ case "dal database, controllare i permessi sulla cartella dati":	$messaggio = "f
 case "Profilo":  				$messaggio = "Profil"; break;
 case "Cliente":  				$messaggio = "Kund"; break;
 case "cliente":  				$messaggio = "kund"; break;
-case "Tabella con le regole di assegnazione 3 del":	$messaggio = "Tabell med &ouml;verl&aring;tningsregel 3 av"; break;
 case "Utente":  				$messaggio = "Anv&auml;ndare"; break;
 case "Periodi_permessi":  			$messaggio = "Tillatna_perioder"; break;
 case "unico":  					$messaggio = "enkel"; break;
@@ -204,12 +202,10 @@ case "clienti</b></div> che non sono associati a nessuna prenotazione e nessun p
 case "Cancella i clienti senza prenotazioni":	$messaggio = "Ta bort kunder utan reservationer"; break;
 case "Metodo pagamento":  			$messaggio = "Betalningsmetod"; break;
 case "Tariffe":  				$messaggio = "Priser"; break;
-case "del":  					$messaggio = "f&ouml;r"; break;
 case "Modifica tutti i campi della tabella":  	$messaggio = "&Auml;ndra alla tabellf&auml;lt"; break;
 case "Modifica i campi della tabella":  	$messaggio = "&Auml;ndra tabellf&auml;lt"; break;
 case "Applica i cambiamenti":  			$messaggio = "Till&auml;mpa &auml;ndringar"; break;
 case "Vedi tutte le prenotazioni":  		$messaggio = "Se alla reservationer"; break;
-case "Tabella con le regole di assegnazione 4 del":	$messaggio = "Tabell f&ouml;r &ouml;verl&aring;telseregel 4 av"; break;
 case "Numero di persone":  			$messaggio = "Antal personder"; break;
 case "assegna_se_":  				$messaggio = "overlat_om_"; break;
 case "più_di_":  				$messaggio = "mindre_an_"; break;
@@ -263,6 +259,8 @@ case "in":  					$messaggio = "in"; break;
 case "giorno":  				$messaggio = "day"; break;
 case "p":  					$messaggio = "p"; break;
 case "Aggiungi":  				$messaggio = "Add"; break;
+case "e":  					$messaggio = "and"; break;
+case "Visualizza Tabelle":  			$messaggio = "View Tables"; break;
 case "Tutte le spese del":  			$messaggio = "All expenses of"; break;
 case "nella cassa principale":  		$messaggio = "in main cashbox"; break;
 case "Tutte le entrate del":  			$messaggio = "All incomes of"; break;
@@ -360,6 +358,21 @@ case "escludere_da_totale_percentuale":  	$messaggio = "exclude_from_percentage_
 case "da varie tariffe":  			$messaggio = "from different<br>rates"; break;
 case "senza letti aggiuntivi":  		$messaggio = "without extra beds"; break;
 case "Premere per modificare":  		$messaggio = "Click to modify"; break;
+case "Converti definitivamente in":  		$messaggio = "Permanently convert into"; break;
+case "al cambio attuale":  			$messaggio = "at current exchange rate"; break;
+case "Le altre valute presenti nella cassa":  	$messaggio = "Other currencies in cashbox"; break;
+case "sono state convertite in":  		$messaggio = "have been converted into"; break;
+case "Tabella con le prenotazioni cancellate":	$messaggio = "Table with deleted reservations"; break;
+case "Prenotazioni cancellate":  		$messaggio = "Deleted reservations"; break;
+case "<b>non importare</b> i prezzi":  		$messaggio = "<b>do not import</b> prices"; break;
+case "Attenzione":  				$messaggio = "Notice"; break;
+case "i periodi aggiunti non potranno più essere eliminati":	$messaggio = "periods added now can't be deleted later"; break;
+case "come tipo di persona":  			$messaggio = "as person type"; break;
+case "e applica la % del tipo di persona":  	$messaggio = "and apply the % of person type"; break;
+case "escludendo":  				$messaggio = "excluding"; break;
+case "includendo solo":  			$messaggio = "including only"; break;
+case "Tabella con le regole di assegnazione":	$messaggio = "Table with the assignment rules"; break;
+case "del":  					$messaggio = "of"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
